.. include:: ../README.rst
  :end-before: The `documentation

Sybil comes with an array of included :doc:`parsers <parsers>`, including ones for
:mod:`doctest` and :rst:dir:`code-block` examples, and
is designed so that it's easy to provide your own additional parsers.

.. toctree::
   :maxdepth: 3

   use.rst
   parsers.rst
   api.rst

.. toctree::
   :maxdepth: 1

   development.rst
   changes.rst
   license.rst

Why Sybil?
==========

Sybil is heavily inspired by `Manuel`__, which was named after a
`Fawlty Towers`__ character, and so it seemed only right to pick another
Fawlty Towers character name for this library.

__ https://pypi.org/project/manuel/

__ https://en.wikipedia.org/wiki/Fawlty_Towers

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

